@@ -1,5 +1,6 @@
 # flake8: noqa
 from miio.airconditioningcompanion import AirConditioningCompanion
+from miio.airconditioningcompanion import AirConditioningCompanionV3
 from miio.airfresh import AirFresh
 from miio.airhumidifier import AirHumidifier
 from miio.airpurifier import AirPurifier
@@ -22,5 +23,6 @@ from miio.waterpurifier import WaterPurifier
 from miio.wifirepeater import WifiRepeater
 from miio.wifispeaker import WifiSpeaker
 from miio.yeelight import Yeelight
+from miio.aqaracamera import AqaraCamera
 
 from miio.discovery import Discovery
