@@ -9,6 +9,11 @@ from .device import Device, DeviceException
 
 _LOGGER = logging.getLogger(__name__)
 
+MODEL_ACPARTNER_V1 = 'lumi.acpartner.v1'
+MODEL_ACPARTNER_V2 = 'lumi.acpartner.v2'
+MODEL_ACPARTNER_V3 = 'lumi.acpartner.v3'
+
+MODELS_SUPPORTED = [MODEL_ACPARTNER_V1, MODEL_ACPARTNER_V2, MODEL_ACPARTNER_V3]
 
 class AirConditioningCompanionException(DeviceException):
     pass
@@ -32,7 +37,8 @@ class FanSpeed(enum.Enum):
 class SwingMode(enum.Enum):
     On = 0
     Off = 1
-    Unknown = 2
+    Unknown2 = 2
+    Unknown7 = 7
 
 
 class Power(enum.Enum):
@@ -83,29 +89,45 @@ class AirConditioningCompanionStatus:
     """Container for status reports of the Xiaomi AC Companion."""
 
     def __init__(self, data):
-        # Device model: lumi.acpartner.v2
-        #
-        # Response of "get_model_and_state":
-        # ['010500978022222102', '010201190280222221', '2']
-        #
-        # AC turned on by set_power=on:
-        # ['010507950000257301', '011001160100002573', '807']
-        #
-        # AC turned off by set_power=off:
-        # ['010507950000257301', '010001160100002573', '6']
-        # ...
-        # ['010507950000257301', '010001160100002573', '1']
+        """
+        Device model: lumi.acpartner.v2
+
+        Response of "get_model_and_state":
+        ['010500978022222102', '010201190280222221', '2']
+
+        AC turned on by set_power=on:
+        ['010507950000257301', '011001160100002573', '807']
+
+        AC turned off by set_power=off:
+        ['010507950000257301', '010001160100002573', '6']
+        ...
+        ['010507950000257301', '010001160100002573', '1']
+
+        Example data payload:
+        { 'model_and_state': ['010500978022222102', '010201190280222221', '2'],
+          'power_socket': 'on' }
+        """
         self.data = data
+        self.model = data['model_and_state'][0]
+        self.state = data['model_and_state'][1]
 
     @property
     def load_power(self) -> int:
         """Current power load of the air conditioner."""
-        return int(self.data[2])
+        return int(self.data['model_and_state'][2])
+
+    @property
+    def power_socket(self) -> Optional[str]:
+        """Current socket power state."""
+        if "power_socket" in self.data and self.data["power_socket"] is not None:
+            return self.data["power_socket"]
+
+        return None
 
     @property
     def air_condition_model(self) -> bytes:
         """Model of the air conditioner."""
-        return bytes.fromhex(self.data[0])
+        return bytes.fromhex(self.model)
 
     @property
     def model_format(self) -> int:
@@ -122,48 +144,48 @@ class AirConditioningCompanionStatus:
         """
         Brand of the air conditioner.
 
-        Known brand ids (int) are 0182, 0097, 0037, 0202, 02782, 0197, 0192.
+        Known brand ids are 0x0182, 0x0097, 0x0037, 0x0202, 0x02782, 0x0197, 0x0192.
         """
-        return int(self.air_condition_model[2:4].hex())
+        return int(self.air_condition_model[2:4].hex(), 16)
 
     @property
     def air_condition_remote(self) -> int:
         """
-        Known remote ids (int):
+        Known remote ids:
 
-        80111111, 80111112 (brand: 182)
-        80222221 (brand: 97)
-        80333331 (brand: 37)
-        80444441 (brand: 202)
-        80555551 (brand: 2782)
-        80777771 (brand: 197)
-        80666661 (brand: 192)
+        0x80111111, 0x80111112 (brand: 0x0182)
+        0x80222221 (brand: 0x0097)
+        0x80333331 (brand: 0x0037)
+        0x80444441 (brand: 0x0202)
+        0x80555551 (brand: 0x2782)
+        0x80777771 (brand: 0x0197)
+        0x80666661 (brand: 0x0192)
 
         """
-        return int(self.air_condition_model[4:8].hex())
+        return int(self.air_condition_model[4:8].hex(), 16)
 
     @property
     def state_format(self) -> int:
         """
         Version number of the state format.
 
-        Known values (int) are: 01, 02, 03
+        Known values are: 1, 2, 3
         """
         return int(self.air_condition_model[8])
 
     @property
     def air_condition_configuration(self) -> int:
-        return self.data[1][2:10]
+        return self.state[2:10]
 
     @property
     def power(self) -> str:
         """Current power state."""
-        return 'on' if int(self.data[1][2:3]) == Power.On.value else 'off'
+        return 'on' if int(self.state[2:3]) == Power.On.value else 'off'
 
     @property
     def led(self) -> Optional[bool]:
         """Current LED state."""
-        state = self.data[1][8:9]
+        state = self.state[8:9]
         if state == Led.On.value:
             return True
 
@@ -182,7 +204,7 @@ class AirConditioningCompanionStatus:
     def target_temperature(self) -> Optional[int]:
         """Target temperature."""
         try:
-            return int(self.data[1][6:8], 16)
+            return int(self.state[6:8], 16)
         except TypeError:
             return None
 
@@ -190,7 +212,7 @@ class AirConditioningCompanionStatus:
     def swing_mode(self) -> Optional[SwingMode]:
         """Current swing mode."""
         try:
-            mode = int(self.data[1][5:6])
+            mode = int(self.state[5:6])
             return SwingMode(mode)
         except TypeError:
             return None
@@ -199,7 +221,7 @@ class AirConditioningCompanionStatus:
     def fan_speed(self) -> Optional[FanSpeed]:
         """Current fan speed."""
         try:
-            speed = int(self.data[1][4:5])
+            speed = int(self.state[4:5])
             return FanSpeed(speed)
         except TypeError:
             return None
@@ -208,7 +230,7 @@ class AirConditioningCompanionStatus:
     def mode(self) -> Optional[OperationMode]:
         """Current operation mode."""
         try:
-            mode = int(self.data[1][3:4])
+            mode = int(self.state[3:4])
             return OperationMode(mode)
         except TypeError:
             return None
@@ -216,6 +238,7 @@ class AirConditioningCompanionStatus:
     def __repr__(self) -> str:
         s = "<AirConditioningCompanionStatus " \
             "power=%s, " \
+            "power_socket=%s, " \
             "load_power=%s, " \
             "air_condition_model=%s, " \
             "model_format=%s, " \
@@ -230,6 +253,7 @@ class AirConditioningCompanionStatus:
             "fan_speed=%s, " \
             "mode=%s>" % \
             (self.power,
+             self.power_socket,
              self.load_power,
              self.air_condition_model.hex(),
              self.model_format,
@@ -250,7 +274,18 @@ class AirConditioningCompanionStatus:
 
 
 class AirConditioningCompanion(Device):
-    """Main class representing Xiaomi Air Conditioning Companion."""
+    """Main class representing Xiaomi Air Conditioning Companion V1 and V2."""
+
+    def __init__(self, ip: str = None, token: str = None, start_id: int = 0,
+                 debug: int = 0, lazy_discover: bool = True,
+                 model: str = MODEL_ACPARTNER_V2) -> None:
+        super().__init__(ip, token, start_id, debug, lazy_discover)
+
+        if model in MODELS_SUPPORTED:
+            self.model = model
+        else:
+            self.model = MODEL_ACPARTNER_V2
+            _LOGGER.error("Device model %s unsupported. Falling back to %s.", model, self.model)
 
     @command(
         default_output=format_output(
@@ -267,8 +302,8 @@ class AirConditioningCompanion(Device):
     )
     def status(self) -> AirConditioningCompanionStatus:
         """Return device status."""
-        status = self.send("get_model_and_state", [])
-        return AirConditioningCompanionStatus(status)
+        status = self.send("get_model_and_state")
+        return AirConditioningCompanionStatus(dict(model_and_state=status))
 
     @command(
         default_output=format_output("Powering the air condition on"),
@@ -298,7 +333,7 @@ class AirConditioningCompanion(Device):
     )
     def learn_result(self):
         """Read the learned command."""
-        return self.send("get_ir_learn_result", [])
+        return self.send("get_ir_learn_result")
 
     @command(
         click.argument("slot", type=int),
@@ -407,3 +442,45 @@ class AirConditioningCompanion(Device):
         configuration = configuration + suffix
 
         return self.send_command(configuration)
+
+
+class AirConditioningCompanionV3(AirConditioningCompanion):
+    def __init__(self, ip: str = None, token: str = None, start_id: int = 0,
+                 debug: int = 0, lazy_discover: bool = True) -> None:
+        super().__init__(ip, token, start_id, debug, lazy_discover,
+                         model=MODEL_ACPARTNER_V3)
+
+    @command(
+        default_output=format_output("Powering socket on"),
+    )
+    def socket_on(self):
+        """Socket power on."""
+        return self.send("toggle_plug", ["on"])
+
+    @command(
+        default_output=format_output("Powering socket off"),
+    )
+    def socket_off(self):
+        """Socket power off."""
+        return self.send("toggle_plug", ["off"])
+
+    @command(
+        default_output=format_output(
+            "",
+            "Power: {result.power}\n"
+            "Power socket: {result.power_socket}\n"
+            "Load power: {result.load_power}\n"
+            "Air Condition model: {result.air_condition_model}\n"
+            "LED: {result.led}\n"
+            "Target temperature: {result.target_temperature} °C\n"
+            "Swing mode: {result.swing_mode}\n"
+            "Fan speed: {result.fan_speed}\n"
+            "Mode: {result.mode}\n"
+        )
+    )
+    def status(self) -> AirConditioningCompanionStatus:
+        """Return device status."""
+        status = self.send("get_model_and_state")
+        power_socket = self.send("get_device_prop", ["lumi.0", "plug_state"])
+        return AirConditioningCompanionStatus(dict(
+            model_and_state=status, power_socket=power_socket[0]))
