@@ -13,13 +13,17 @@ _LOGGER = logging.getLogger(__name__)
 MODEL_CHUANGMI_PLUG_V3 = 'chuangmi.plug.v3'
 MODEL_CHUANGMI_PLUG_V1 = 'chuangmi.plug.v1'
 MODEL_CHUANGMI_PLUG_M1 = 'chuangmi.plug.m1'
+MODEL_CHUANGMI_PLUG_M3 = 'chuangmi.plug.m3'
 MODEL_CHUANGMI_PLUG_V2 = 'chuangmi.plug.v2'
+MODEL_CHUANGMI_PLUG_HMI205 = 'chuangmi.plug.hmi205'
 
 AVAILABLE_PROPERTIES = {
     MODEL_CHUANGMI_PLUG_V1: ['on', 'usb_on', 'temperature'],
     MODEL_CHUANGMI_PLUG_V3: ['on', 'usb_on', 'temperature', 'wifi_led'],
     MODEL_CHUANGMI_PLUG_M1: ['power', 'temperature'],
+    MODEL_CHUANGMI_PLUG_M3: ['power', 'temperature'],
     MODEL_CHUANGMI_PLUG_V2: ['power', 'temperature'],
+    MODEL_CHUANGMI_PLUG_HMI205: ['power', 'temperature'],
 }
 
 
@@ -93,7 +97,7 @@ class ChuangmiPlugStatus:
 
 
 class ChuangmiPlug(Device):
-    """Main class representing the Chuangmi Plug V1 and V3."""
+    """Main class representing the Chuangmi Plug."""
 
     def __init__(self, ip: str = None, token: str = None, start_id: int = 0,
                  debug: int = 0, lazy_discover: bool = True,
