@@ -4,7 +4,7 @@ import pytest
 
 from miio import PhilipsMoonlight
 from miio.philips_moonlight import PhilipsMoonlightStatus, PhilipsMoonlightException
-from miio.utils import int_to_rgb
+from miio.utils import int_to_rgb, rgb_to_int
 from .dummies import DummyDevice
 
 
@@ -30,15 +30,16 @@ class DummyPhilipsMoonlight(DummyDevice, PhilipsMoonlight):
             'set_power': lambda x: self._set_state("pow", x),
             'set_bright': lambda x: self._set_state("bri", x),
             'set_cct': lambda x: self._set_state("cct", x),
-            'set_rgb': lambda x: self._set_state("rgb", x),
+            'set_rgb': lambda x: self._set_state("rgb", [rgb_to_int(x)]),
             'apply_fixed_scene': lambda x: self._set_state("snm", x),
+            'go_night': lambda x: self._set_state("snm", [6]),
             'set_bricct': lambda x: (
                 self._set_state('bri', [x[0]]),
-                self._set_state('cct', [x[1]])
+                self._set_state('cct', [x[1]]),
             ),
             'set_brirgb': lambda x: (
-                self._set_state('bri', [x[0]]),
-                self._set_state('rgb', [x[1]])
+                self._set_state('rgb', [rgb_to_int((x[0], x[1], x[2]))]),
+                self._set_state('bri', [x[3]]),
             )
         }
         super().__init__(args, kwargs)
@@ -192,22 +193,19 @@ class TestPhilipsMoonlight(TestCase):
         def rgb():
             return self.device.status().rgb
 
-        self.device.set_brightness_and_rgb(20, 0)
+        self.device.set_brightness_and_rgb(20, (0, 0, 0))
         assert brightness() == 20
         assert rgb() == (0, 0, 0)
-        self.device.set_brightness_and_rgb(31, 16711680)
+        self.device.set_brightness_and_rgb(31, (255, 0, 0))
         assert brightness() == 31
         assert rgb() == (255, 0, 0)
-        self.device.set_brightness_and_rgb(100, 16777215)
+        self.device.set_brightness_and_rgb(100, (255, 255, 255))
         assert brightness() == 100
         assert rgb() == (255, 255, 255)
 
         with pytest.raises(PhilipsMoonlightException):
             self.device.set_brightness_and_rgb(-1, 10)
 
-        with pytest.raises(PhilipsMoonlightException):
-            self.device.set_brightness_and_rgb(10, -1)
-
         with pytest.raises(PhilipsMoonlightException):
             self.device.set_brightness_and_rgb(0, 10)
 
@@ -215,7 +213,22 @@ class TestPhilipsMoonlight(TestCase):
             self.device.set_brightness_and_rgb(101, 10)
 
         with pytest.raises(PhilipsMoonlightException):
-            self.device.set_brightness_and_rgb(10, 16777216)
+            self.device.set_brightness_and_rgb(10, (-1, 0, 0))
+
+        with pytest.raises(PhilipsMoonlightException):
+            self.device.set_brightness_and_rgb(10, (256, 0, 0))
+
+        with pytest.raises(PhilipsMoonlightException):
+            self.device.set_brightness_and_rgb(10, (0, -1, 0))
+
+        with pytest.raises(PhilipsMoonlightException):
+            self.device.set_brightness_and_rgb(10, (0, 256, 0))
+
+        with pytest.raises(PhilipsMoonlightException):
+            self.device.set_brightness_and_rgb(10, (0, 0, -1))
+
+        with pytest.raises(PhilipsMoonlightException):
+            self.device.set_brightness_and_rgb(10, (0, 0, 256))
 
     def test_set_scene(self):
         def scene():
@@ -223,8 +236,8 @@ class TestPhilipsMoonlight(TestCase):
 
         self.device.set_scene(1)
         assert scene() == 1
-        self.device.set_scene(2)
-        assert scene() == 2
+        self.device.set_scene(6)
+        assert scene() == 6
 
         with pytest.raises(PhilipsMoonlightException):
             self.device.set_scene(-1)
@@ -233,4 +246,4 @@ class TestPhilipsMoonlight(TestCase):
             self.device.set_scene(0)
 
         with pytest.raises(PhilipsMoonlightException):
-            self.device.set_scene(5)
+            self.device.set_scene(7)
