@@ -71,6 +71,15 @@ class Vacuum(Device):
         """Pause cleaning."""
         return self.send("app_pause")
 
+    @command()
+    def resume_or_start(self):
+        """A shortcut for resuming or starting cleaning."""
+        status = self.status()
+        if status.in_zone_cleaning and status.is_paused:
+            return self.resume_zoned_clean()
+
+        return self.start()
+
     @command()
     def home(self):
         """Stop cleaning and return home."""
@@ -95,6 +104,11 @@ class Vacuum(Device):
         :param List zones: List of zones to clean: [[x1,y1,x2,y2, iterations],[x1,y1,x2,y2, iterations]]"""
         return self.send("app_zoned_clean", zones)
 
+    @command()
+    def resume_zoned_clean(self):
+        """Resume zone cleaning after being paused."""
+        return self.send("resume_zoned_clean")
+
     @command()
     def manual_start(self):
         """Start manual control mode."""
@@ -183,15 +197,107 @@ class Vacuum(Device):
         # returns ['retry'] without internet
         return self.send("get_map_v1")
 
+    @command(
+        click.argument("start", type=bool)
+    )
+    def edit_map(self, start):
+        """Start map editing?"""
+        if start:
+            return self.send("start_edit_map")[0] == "ok"
+        else:
+            return self.send("end_edit_map")[0] == "ok"
+
+    @command(
+        click.option("--version", default=1)
+    )
+    def fresh_map(self, version):
+        """Return fresh map?"""
+        if version == 1:
+            return self.send("get_fresh_map")
+        elif version == 2:
+            return self.send("get_fresh_map_v2")
+        else:
+            raise VacuumException("Unknown map version: %s" % version)
+
+    @command(
+        click.option("--version", default=1)
+    )
+    def persist_map(self, version):
+        """Return fresh map?"""
+        if version == 1:
+            return self.send("get_persist_map")
+        elif version == 2:
+            return self.send("get_persist_map_v2")
+        else:
+            raise VacuumException("Unknown map version: %s" % version)
+
+    @command(
+        click.argument("x1", type=int),
+        click.argument("y1", type=int),
+        click.argument("x2", type=int),
+        click.argument("y2", type=int),
+    )
+    def create_software_barrier(self, x1, y1, x2, y2):
+        """Create software barrier (gen2 only?).
+
+        NOTE: Multiple nogo zones and barriers could be added by passing
+        a list of them to save_map.
+
+        Requires new fw version.
+        3.3.9_001633+?
+        """
+        # First parameter indicates the type, 1 = barrier
+        payload = [1, x1, y1, x2, y2]
+        return self.send("save_map", payload)[0] == "ok"
+
+    @command(
+        click.argument("x1", type=int),
+        click.argument("y1", type=int),
+        click.argument("x2", type=int),
+        click.argument("y2", type=int),
+        click.argument("x3", type=int),
+        click.argument("y3", type=int),
+        click.argument("x4", type=int),
+        click.argument("y4", type=int),
+    )
+    def create_nogo_zone(self, x1, y1, x2, y2, x3, y3, x4, y4):
+        """Create a rectangular no-go zone (gen2 only?).
+
+        NOTE: Multiple nogo zones and barriers could be added by passing
+        a list of them to save_map.
+
+        Requires new fw version.
+        3.3.9_001633+?
+        """
+        # First parameter indicates the type, 0 = zone
+        payload = [0, x1, y1, x2, y2, x3, y3, x4, y4]
+        return self.send("save_map", payload)[0] == "ok"
+
+    @command(
+        click.argument("enable", type=bool)
+    )
+    def enable_lab_mode(self, enable):
+        """Enable persistent maps and software barriers.
+
+        This is required to use create_nogo_zone and create_software_barrier
+        commands."""
+        return self.send("set_lab_status", int(enable))['ok']
+
     @command()
     def clean_history(self) -> CleaningSummary:
         """Return generic cleaning history."""
         return CleaningSummary(self.send("get_clean_summary"))
 
     @command()
-    def last_clean_details(self) -> CleaningDetails:
-        """Return details from the last cleaning."""
-        last_clean_id = self.clean_history().ids.pop(0)
+    def last_clean_details(self) -> Optional[CleaningDetails]:
+        """Return details from the last cleaning.
+
+        Returns None if there has been no cleanups."""
+        history = self.clean_history()
+        if not history.ids:
+            return None
+
+        last_clean_id = history.ids.pop(0)
         return self.clean_details(last_clean_id, return_list=False)
 
     @command(
