@@ -10,7 +10,6 @@ from pprint import pformat as pf
 from typing import Any, List  # noqa: F401
 
 import click
-import pretty_cron
 from appdirs import user_cache_dir
 from tqdm import tqdm
 
@@ -342,7 +341,7 @@ def timer(ctx, vac: miio.Vacuum):
         click.echo("  %s" % timer.cron)
         min, hr, x, y, days = timer.cron.split(' ')
         cron = "%s %s %s %s %s" % (min, hr, x, y, days)
-        click.echo("  %s" % pretty_cron.prettify_cron(cron))
+        click.echo("  %s" % cron)
 
 
 @timer.command()
@@ -418,15 +417,15 @@ def cleaning_history(vac: miio.Vacuum):
                                                   res.total_area))
     click.echo()
     for idx, id_ in enumerate(res.ids):
-        for e in vac.clean_details(id_):
-            color = "green" if e.complete else "yellow"
-            click.echo(click.style(
-                "Clean #%s: %s-%s (complete: %s, error: %s)" % (
-                    idx, e.start, e.end, e.complete, e.error),
-                bold=True, fg=color))
-            click.echo("  Area cleaned: %s m²" % e.area)
-            click.echo("  Duration: (%s)" % e.duration)
-            click.echo()
+        details = vac.clean_details(id_, return_list=False)
+        color = "green" if details.complete else "yellow"
+        click.echo(click.style(
+            "Clean #%s: %s-%s (complete: %s, error: %s)" % (
+                idx, details.start, details.end, details.complete, details.error),
+            bold=True, fg=color))
+        click.echo("  Area cleaned: %s m²" % details.area)
+        click.echo("  Duration: (%s)" % details.duration)
+        click.echo()
 
 
 @cli.command()
