@@ -31,6 +31,9 @@ error_codes = {  # from vacuum_cleaner-EN.pdf
     17: "Side brushes problem, reboot me",
     18: "Suction fan problem",
     19: "Unpowered charging station",
+    21: "Laser disance sensor blocked",
+    22: "Clean the dock charging contacts",
+    23: "Docking station not reachable",
 }
 
 
@@ -138,6 +141,16 @@ class VacuumStatus:
         # we are not using in_cleaning as it does not seem to work properly.
         # return bool(self.data["in_cleaning"])
 
+    @property
+    def in_zone_cleaning(self) -> bool:
+        """Return True if the vacuum is in zone cleaning mode."""
+        return self.data["in_cleaning"] == 2
+
+    @property
+    def is_paused(self) -> bool:
+        """Return True if vacuum is paused."""
+        return self.state_code == 10
+
     @property
     def is_on(self) -> bool:
         """True if device is currently cleaning (either automatic, manual,
